@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: zhuyuliang <zhuyuliang@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 
 #include "mpv_proxy.h"
@@ -363,7 +335,7 @@ namespace dmr {
         pixmap=pixmap.fromImage(img);
 
         QPixmap pixmap2;
-        QImage img1=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        QImage img1=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap2=pixmap2.fromImage(img1);
 
         QPainter painter(&pixmap);
@@ -378,7 +350,7 @@ namespace dmr {
         pixmap3=pixmap3.fromImage(image);
 
         QPixmap pixmap4;
-        QImage img2=utils::LoadHiDPIImage(":/resources/icons/dark/init-splash.svg");
+        QImage img2=QIcon::fromTheme("deepin-movie").pixmap(130, 130).toImage();
         pixmap4=pixmap4.fromImage(img2);
 
         QPainter painter1(&pixmap3);
@@ -771,12 +743,15 @@ namespace dmr {
                     m_vbo.bind();
                     m_pGlProg->bind();
                     m_pGlProg->setUniformValue("bg", color);
-
-                    QOpenGLTexture *pGLTexture = m_pLightTex;
-                    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
-                    if (themeType == DGuiApplicationHelper::DarkType) {
-                        pGLTexture = m_pDarkTex;
-                    }
+                    prepareSplashImages();
+                    QOpenGLTexture *pGLTexture;
+                    m_pLightTex->setData(m_imgBgLight);
+                    pGLTexture = m_pLightTex;
+                    //和产品、ui商议深色主题下去除深色背景效果
+//                    DGuiApplicationHelper::ColorType themeType = DGuiApplicationHelper::instance()->themeType();
+//                    if (themeType == DGuiApplicationHelper::DarkType) {
+//                        pGLTexture = m_pDarkTex;
+//                    }
                     pGLTexture->bind();
                     pGLFunction->glActiveTexture(GL_TEXTURE0);
                     pGLFunction->glDrawArrays(GL_TRIANGLES, 0, 6);
@@ -836,7 +811,8 @@ namespace dmr {
     {
         if(!m_pVideoTex){
             QFileInfo fi("/dev/mwv206_0");
-            if (fi.exists()) {
+            QFileInfo jmfi("/dev/jmgpu");
+            if (fi.exists() || jmfi.exists()) {
                 m_pVideoTex = new QOpenGLTexture(image, QOpenGLTexture::DontGenerateMipMaps);
             } else {
                 m_pVideoTex = new QOpenGLTexture(image, QOpenGLTexture::GenerateMipMaps);
