@@ -343,6 +343,14 @@ mpv_handle *MpvProxy::mpv_init()
 
     if (DecodeMode::SOFTWARE == m_decodeMode) { //1.设置软解
         my_set_property(pHandle, "hwdec", "no");
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (!CompositingManager::get().hascard()) {
+            qInfo() << "修改音视频同步模式";
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "vo", "x11");
+            m_sInitVo = "x11";
+        }
+#endif
     } else if (DecodeMode::AUTO == m_decodeMode) { //2.设置自动
         //2.1特殊硬件
         //景嘉微显卡目前只支持vo=xv，等日后升级代码需要酌情修改。
@@ -397,8 +405,13 @@ mpv_handle *MpvProxy::mpv_init()
             my_set_property(pHandle, "video-sync", "desync");
         }
         if (!fi.exists() && !jmfi.exists() && !mtfi.exists()) {
-            my_set_property(pHandle, "vo", "x11");
-            m_sInitVo = "x11";
+            if(CompositingManager::get().property("directRendering").toBool()) {
+                my_set_property(pHandle, "vo", "gpu,x11");
+                m_sInitVo = "gpu,x11";
+            } else {
+                my_set_property(pHandle, "vo", "x11");
+                m_sInitVo = "x11";
+            }
         }
 #elif defined (__sw_64__)
         //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
@@ -409,6 +422,11 @@ mpv_handle *MpvProxy::mpv_init()
             my_set_property(pHandle, "vo", "gpu,xv,x11");
             m_sInitVo = "gpu,xv,x11";
         }
+        if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(pHandle, "hwdec", "vaapi");
+            my_set_property(pHandle, "vo", "vaapi");
+            m_sInitVo = "vaapi";
+        }
 #else
         //去除9200显卡适配
         QFileInfo sjmfi("/dev/jmgpu");
@@ -422,9 +440,39 @@ mpv_handle *MpvProxy::mpv_init()
         }
         //TODO(xxxxpengfei)：暂未处理intel集显情况
         if (CompositingManager::get().isZXIntgraphics() && !jmflag) {
-            my_set_property(pHandle, "vo", "gpu");
+            QProcess process;
+            QStringList options;
+            options << "-c" << QString("apt policy cx4-linux-graphics-driver-dri | sed -n \'2p\'");
+            process.start("/bin/bash", options);
+            process.waitForFinished();
+            process.waitForReadyRead();
+
+            QString comStr = process.readAllStandardOutput();
+            comStr = comStr.right(3).left(2);
+            int version = comStr.toInt();
+            if (version >= 10) {
+                my_set_property(pHandle, "vo", "vaapi");
+                my_set_property(pHandle, "hwdec", "vaapi");
+                m_sInitVo = "vaapi";
+            } else {
+                my_set_property(pHandle, "vo", "gpu");
+                m_sInitVo = "gpu";
+            }
         }
 #endif
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(pHandle, "hwdec", "no");
+            my_set_property(pHandle, "vo", "x11");
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
+        QDir innodir("/sys/bus/platform/drivers/inno-codec");
+        if ( innodir.exists()) {
+            my_set_property(pHandle, "vo", "gpu,x11");
+            m_sInitVo = "gpu,x11";
+        }
     } else { //3.设置硬解
         QFileInfo fi("/dev/mwv206_0");
         QFileInfo jmfi("/dev/jmgpu");
@@ -457,7 +505,39 @@ mpv_handle *MpvProxy::mpv_init()
         //Synchronously modify the video output of the SW platform vdpau(powered by zhangfl)
         my_set_property(pHandle, "vo", "gpu,x11");
         m_sInitVo = "gpu,x11";
+#elif defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (!CompositingManager::get().hascard()) {
+            qInfo() << "修改音视频同步模式";
+            my_set_property(pHandle, "video-sync", "desync");
+        }
+        if (!fi.exists() && !jmfi.exists()) {
+            if(CompositingManager::get().property("directRendering").toBool()) {
+                my_set_property(pHandle, "vo", "gpu,x11");
+                m_sInitVo = "gpu,x11";
+            } else {
+                my_set_property(pHandle, "vo", "x11");
+                m_sInitVo = "x11";
+            }
+        }
 #endif
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(pHandle, "hwdec", "no");
+            my_set_property(pHandle, "vo", "x11");
+            my_set_property(pHandle, "video-sync", "desync");
+            my_set_property(pHandle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
+        QDir innodir("/sys/bus/platform/drivers/inno-codec");
+        if ( innodir.exists()) {
+            my_set_property(pHandle, "vo", "gpu,x11");
+            m_sInitVo = "gpu,x11";
+        }
+        if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(pHandle, "hwdec", "vaapi");
+            my_set_property(pHandle, "vo", "vaapi");
+            m_sInitVo = "vaapi";
+        }
     }
 
     if (composited) {
@@ -1161,18 +1241,30 @@ void MpvProxy::refreshDecode()
                 my_set_property(m_handle, "vo", "gpu");
             } else if (CompositingManager::get().isOnlySoftDecode()) { //2.2.1.2 鲲鹏920 || 曙光+英伟达 || 浪潮
                 my_set_property(m_handle, "hwdec", "no");
+            } else if (CompositingManager::get().isSpecialControls()) {
+                my_set_property(m_handle, "hwdec", "vaapi");
             } else { //2.2.2 非特殊硬件 + 非特殊格式
                  my_set_property(m_handle, "hwdec","auto");
                 //bIsCanHwDec ? my_set_property(m_handle, "hwdec", canHwTypes.join(',')) : my_set_property(m_handle, "hwdec", "no");
             }
         }
+
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(m_handle, "vo", "x11");
+            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(m_handle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
     } else { //3.设置硬解
 #ifndef _LIBDMR_
 
-#if defined (__aarch64__) || defined (__sw_64__)
+#if defined (__aarch64__)
         // 鲲鹏920 || 曙光+英伟达 || 浪潮
         if (!CompositingManager::get().hascard() || CompositingManager::get().isOnlySoftDecode()) {
             my_set_property(m_handle, "hwdec", "no");
+        } else if (CompositingManager::get().isSpecialControls()) {
+            my_set_property(m_handle, "hwdec", "vaapi");
         } else {
             my_set_property(m_handle, "hwdec","auto");
         }
@@ -1199,20 +1291,26 @@ void MpvProxy::refreshDecode()
         if (fi.exists() || jmfi.exists()) {
             QDir sdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv206"); //判断是否安装核外驱动
             QDir jmdir(QLibraryInfo::location(QLibraryInfo::LibrariesPath) +QDir::separator() +"mwv207");
-            if(sdir.exists())
-            {
-                 my_set_property(m_handle, "hwdec", "vdpau");
-            } else {
-                 my_set_property(m_handle, "hwdec", "auto");
-            }
-            if (!sdir.exists() && jmdir.exists()) {
+            if(sdir.exists() && fi.exists()) {
+                my_set_property(m_handle, "hwdec", "vdpau");
+            }else if (jmfi.exists() && jmdir.exists()) {
                 my_set_property(m_handle, "hwdec", "vaapi");
+            }else {
+                my_set_property(m_handle, "hwdec", "auto");
             }
         } else if (X100GPU.exists() && X100VPU.exists()) {
             my_set_property(m_handle, "hwdec", "ftomx-copy");
             my_set_property(m_handle, "vo", "gpu");
         }
 
+        if (QFile::exists("/usr/local/ctyun/clink/Mirror/Registry/Default")) {
+            my_set_property(m_handle, "hwdec", "no");
+            my_set_property(m_handle, "vo", "x11");
+            my_set_property(m_handle, "video-sync", "desync");
+            my_set_property(m_handle, "profile", "sw-fast");
+            m_sInitVo = "x11";
+        }
+
         //play.conf
         CompositingManager::get().getMpvConfig(m_pConfig);
         QMap<QString, QString>::iterator iter = m_pConfig->begin();
