@@ -98,6 +98,7 @@ CompositingManager::CompositingManager()
 {
     initMember();
     bool isDriverLoaded = isDriverLoadedCorrectly();
+    setProperty("directRendering", isDriverLoaded); //是否支持直接渲染
     softDecodeCheck();   //检测是否是kunpeng920（是否走软解码）
 
 //    bool isI915 = false;
@@ -288,7 +289,7 @@ bool CompositingManager::isMpvExists()
     QDir dir;
     QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
     dir.setPath(path);
-    QStringList list = dir.entryList(QStringList() << (QString("libmpv.so.1") + "*"), QDir::NoDotAndDotDot | QDir::Files);
+    static QStringList list = dir.entryList(QStringList() << (QString("libmpv.so.1") + "*"), QDir::NoDotAndDotDot | QDir::Files);
     if (list.contains("libmpv.so.1")) {
         return true;
     }
@@ -348,6 +349,21 @@ void CompositingManager::softDecodeCheck()
         board.close();
     }
 
+    if (m_cpuModelName.contains("KX-U6780A")) {
+        QFile modaInfo("/sys/class/dmi/id/modalias");
+        if (modaInfo.open(QIODevice::ReadOnly)) {
+            QString data = modaInfo.readAll();
+            QStringList modaList = data.split(":");
+            qInfo() << data;
+            if (modaList.size() >= 7) {
+                if (modaList[6].contains("M630Z"))
+                    m_bOnlySoftDecode = true;
+            }
+
+            modaInfo.close();
+        }
+    }
+
     if ((runningOnNvidia() && m_boardVendor.contains("Sugon"))
             || m_cpuModelName.contains("Kunpeng 920")) {
         m_bOnlySoftDecode = true;
@@ -356,7 +372,7 @@ void CompositingManager::softDecodeCheck()
         m_bHasCard = true;
     }
 
-    m_setSpecialControls = m_boardVendor.contains("Ruijie");
+    m_setSpecialControls = m_boardVendor.contains("PHYTIUM");
 
     //判断N卡驱动版本
     QFile nvidiaVersion("/proc/driver/nvidia/version");
@@ -486,8 +502,12 @@ bool CompositingManager::isDriverLoadedCorrectly()
     static QRegExp dri_ok("direct rendering: DRI\\d+ enabled");
     static QRegExp swrast("GLX: Initialized DRISWRAST");
     static QRegExp regZX("loading driver: zx");
+    static QRegExp regCX4("loading driver: cx4");
+    static QRegExp arise("loading driver: arise");
     static QRegExp controller("1ec8");
-
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+    static QRegExp rendering("direct rendering");
+#endif
     QString xorglog = QString("/var/log/Xorg.%1.log").arg(QX11Info::appScreen());
     qInfo() << "check " << xorglog;
     QFile f(xorglog);
@@ -508,13 +528,18 @@ bool CompositingManager::isDriverLoadedCorrectly()
             qInfo() << "dri enabled successfully";
             return true;
         }
-
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+        if (rendering.indexIn(ln.toLower()) != -1) {
+            qInfo() << "_loongarch dri enabled successfully";
+            return true;
+        }
+#endif
         if (swrast.indexIn(ln) != -1) {
             qInfo() << "swrast driver used";
             return false;
         }
 
-        if (regZX.indexIn(ln) != -1) {
+        if (regZX.indexIn(ln) != -1 || regCX4.indexIn(ln) != -1 || arise.indexIn(ln) != -1) {
             m_bZXIntgraphics = true;
         }
 
@@ -524,6 +549,9 @@ bool CompositingManager::isDriverLoadedCorrectly()
         }
     }
     f.close();
+#if defined(_loongarch) || defined(__loongarch__) || defined(__loongarch64)
+    return false;
+#endif
     return true;
 }
 
